# Table of Contents

- [leanix-adapter-for-sap-integration-suite](<./leanix-adapter-for-sap-integration-suite.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [LeanIX Adapter for SAP Integration Suite](<./LeanIX-Adapter-for-SAP-Integration-Suite.md>)
  - [Overview](<./LeanIX-Adapter-for-SAP-Integration-Suite/Overview.md>)
  - [Benefits](<./LeanIX-Adapter-for-SAP-Integration-Suite/Benefits.md>)
  - [Key Features](<./LeanIX-Adapter-for-SAP-Integration-Suite/Key-Features.md>)
  - [Use Cases](<./LeanIX-Adapter-for-SAP-Integration-Suite/Use-Cases.md>)
  - [Documentation](<./LeanIX-Adapter-for-SAP-Integration-Suite/Documentation.md>)
